# rpmbuild parameters:
# --without check: Do not run the testsuite.  Default is to run it.

# host != target would cause REMOTE_ONLY build even if building i386 on x86_64.
%global _host %{_target_platform}

%define major   8
%define libname %mklibname unwind %{major}
%define devname %mklibname unwind -d

%define majorcoredump 0
%define libcoredump   %mklibname unwind-coredump %{majorcoredump}

Summary:        An unwinding library
Name:           libunwind
Version:        1.8.1
Release:        %mkrel 2
License:        BSD
Group:          Development/Tools
URL:            https://savannah.nongnu.org/projects/libunwind
Source0:        https://github.com/libunwind/libunwind/releases/download/v%{version}/%{name}-%{version}.tar.gz
#Fedora specific patch
Patch1:         libunwind-arm-default-to-exidx.patch
# Make libunwind.h multilib friendly
Patch2:         libunwind-1.3.1-multilib-fix.patch
# Fix C23 issue
Patch3:         https://github.com/libunwind/libunwind/commit/457612f470f8c0e718cdf7f14ef1ecb583f3b3a6.patch

BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  texlive-collection-basic

%description
Libunwind provides a C ABI to determine the call-chain of a program.

%package -n %{libname}
Summary:        An unwinding library
Group:          System/Libraries

%description -n %{libname}
Libunwind provides a C ABI to determine the call-chain of a program.

%package -n %{libcoredump}
Summary:         An unwinding library
Group:           System/Libraries

%description -n %{libcoredump}
Libunwind provides a C ABI to determine the call-chain of a program.

%package -n %{devname}
Summary:        Development package for libunwind
Group:          Development/Tools
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libcoredump} = %{version}-%{release}
Provides:       unwind-devel
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
The libunwind-devel package includes the libraries and header files for
libunwind.

%prep
%autosetup -p1

%build
autoreconf -vfi
%configure --enable-static --enable-shared --enable-setjmp=no
%make_build

%install
%make_install

find %{buildroot} -name "*.la" -delete

# /usr/include/libunwind-ptrace.h
# [...] aren't really part of the libunwind API.  They are implemented in
# a archive library called libunwind-ptrace.a.
mv -f %{buildroot}%{_libdir}/libunwind-ptrace.a %{buildroot}%{_libdir}/libunwind-ptrace.a-save
rm -f %{buildroot}%{_libdir}/libunwind*.a
mv -f %{buildroot}%{_libdir}/libunwind-ptrace.a-save %{buildroot}%{_libdir}/libunwind-ptrace.a

# The tests want this one.
# rm -f %{buildroot}%{_libdir}/libunwind-ptrace*.so*

# fix multilib conflicts
touch -r NEWS %{buildroot}%{_includedir}/libunwind.h

# Do not install the test files
rm -rf %{buildroot}%{_libexecdir}/%{name}

%check
%if 0%{?_with_check:1} || 0%{?_with_testsuite:1}
echo ====================TESTING=========================
make check || true
echo ====================TESTING END=====================
%else
echo ====================TESTSUITE DISABLED=========================
%endif

%files -n %{libname}
%license COPYING
%doc README NEWS
%{_libdir}/libunwind-*.so.%{major}{,.*}
%{_libdir}/libunwind.so.%{major}{,.*}

%files -n %{libcoredump}
%{_libdir}/libunwind-coredump.so.%{majorcoredump}{,.*}

%files -n %{devname}
%{_libdir}/libunwind*.so
%{_libdir}/libunwind-ptrace.*
%{_mandir}/*/*
%{_libdir}/pkgconfig/libunwind*.pc
# <unwind.h> does not get installed for REMOTE_ONLY targets - check it.
%{_includedir}/unwind.h
%{_includedir}/libunwind*.h


%changelog
* Mon May 19 2025 ns80 <ns80> 1.8.1-2.mga10
+ Revision: 2184768
- resync a bit with Fedora to try to fix building with GCC 15

* Thu Jun 13 2024 daviddavid <daviddavid> 1.8.1-1.mga10
+ Revision: 2072944
- new version: 1.8.1

* Thu Feb 15 2024 daviddavid <daviddavid> 1.8.0-1.mga10
+ Revision: 2041508
- new version: 1.8.0

* Tue Oct 17 2023 daviddavid <daviddavid> 1.7.2-1.mga10
+ Revision: 1997911
- new version: 1.7.2

* Sat Nov 05 2022 tv <tv> 1.6.2-3.mga9
+ Revision: 1903903
- Rebuild in order to restore after llvm-libunwind introduction

* Wed Mar 16 2022 umeabot <umeabot> 1.6.2-2.mga9
+ Revision: 1794765
- Mageia 9 Mass Rebuild

* Thu Jan 27 2022 mrambo3501 <mrambo3501> 1.6.2-1.mga9
+ Revision: 1770054
- version 1.6.2
- rediff Patch1

* Thu Nov 19 2020 luigiwalser <luigiwalser> 1.5.0-1.mga8
+ Revision: 1647386
- 1.5.0
- build fixes from fedora

* Tue Aug 04 2020 joequant <joequant> 1.2-4.mga8
+ Revision: 1610990
- redo legacy build

* Thu Feb 13 2020 umeabot <umeabot> 1.2-3.mga8
+ Revision: 1514700
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.2-2.mga7
+ Revision: 1299199
- Mageia 7 Mass Rebuild

* Wed Jun 07 2017 luigiwalser <luigiwalser> 1.2-1.mga6
+ Revision: 1107166
- 1.2
- remove upstreamed patches
- replace patch1 with configure argument (thanks fedora)

* Sun Jan 22 2017 wally <wally> 1.1-8.mga6
+ Revision: 1082913
- add arm patch from Fedora

* Sun Jan 22 2017 wally <wally> 1.1-7.mga6
+ Revision: 1082909
- fix libification

* Thu Feb 11 2016 umeabot <umeabot> 1.1-6.mga6
+ Revision: 955814
- Mageia 6 Mass Rebuild

* Tue Jul 21 2015 luigiwalser <luigiwalser> 1.1-5.mga6
+ Revision: 855948
- add patch from fedora to fix CVE-2015-3239

* Wed Oct 15 2014 umeabot <umeabot> 1.1-4.mga5
+ Revision: 741370
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1-3.mga5
+ Revision: 681829
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.1-2.mga4
+ Revision: 527675
- Mageia 4 Mass Rebuild
+ tv <tv>
- fix description

* Mon Jun 10 2013 tv <tv> 1.1-1.mga4
+ Revision: 441709
- new release

* Sun Jan 27 2013 tmb <tmb> 1.0.1-1.mga3
+ Revision: 392716
- fix group
- fix build
- spec cleanups
- import from fedora


* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Feb 15 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0.1-3
- Add patch to fix build on ARM

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Sep 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 1.0.1-1.fc17
- Upgrade to the upstream release. (BZ 738595).
- Use official distribution URL for %%{source}.

* Thu Jun 02 2011 Paul Whalen <paul.whalen@senecac.on.ca> - 0.99-3.20110424git1e10c293
- Added arm macro to ExclusiveArch

* Mon May  9 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-2.20110424git1e10c293
- Install static libunwind-ptrace library into system (for ltrace, BZ 703159).

* Sun Apr 24 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-1.20110424git1e10c293
- Rebase to the upstream post-0.99 snapshot (BZ 697453).

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.99-0.16.20090430betagit4b8404d1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 0.99-0.15.20090430betagit4b8404d1
- Rebuilt for gcc bug 634757

* Sat Sep 11 2010 Parag Nemade <paragn AT fedoraproject.org> 0.99-0.14.20090430betagit4b8404d1.fc15
- Merge-review cleanup (#226052)

* Fri Dec  4 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.99-0.13.20090430betagit4b8404d1
- The devel package now requires also base package's %%{release}.
- Update the obsolete macro %%{package_version}.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.99-0.12.20090430betagit4b8404d1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 15 2009 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.11.20090430betagit4b8404d1
- Disable the libunwind-setjmp library as no longer compatible with glibc and
  no Fedora dependencies on it (FTBSFS BZ 511562).

* Thu Apr 30 2009 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.10.20090430betagit4b8404d1
- Fix the ia64 variant of GetIPInfo() (BZ 480412).

* Mon Apr 13 2009 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.9.20090413betagitb483ea3f
- Rebase the package on the upstream variant: http://www.nongnu.org/libunwind/
  - Drop the patch libunwind-snap-070224-frysk20070405cvs.patch
    as even frysk-0.4-8.fc11 still has this library bundled statically.
- Disable the testsuite by default during the build.
  - It should be run separately as it crashes some ia64 kernels.
  - Drop the patch libunwind-snap-070224-orphanripper.patch.
- Drop the patch libunwind-snap-070224-dprintf-vs-stdio.h as no longer needed.
- Drop libunwind-snap-070224-multilib-rh342451.patch as accepted upstream.
- Fix and enable ppc (ppc32) arch.

* Tue Mar  3 2009 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.8.frysk20070405cvs
- Fix .spec ExclusiveArch from i386 to %%{ix86}.
- Remove `BuildRequires: glibc gcc make tar gzip' - minimum build environment.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.99-0.7.frysk20070405cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Sep 22 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.6.frysk20070405cvs
- Fix build error due to a `dprintf' conflict on recent glibc.
- New rpmbuild parameter: --without check

* Sun Feb 24 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.5.frysk20070405cvs
- Fix the multilib conflicts (BZ 342451).

* Sun Feb 24 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.4.frysk20070405cvs
- Abort the possibly hung up testcases after 120 seconds (BZ 427850, BZ 434147).

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.99-0.3.frysk20070405cvs
- Autorebuild for GCC 4.3

* Sun Apr 22 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.2.frysk20070405cvs
- Require conflict with gdb < gdb-6.6-9 as it would not find `libunwind.so'.
- Fixed (unused - commented) rule for a RPM build with embedded debug info.

* Thu Apr  5 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.99-0.1.frysk20070405cvs
- Update to the upstream snapshot snap-070224.
- Use the Frysk's modified version, currently snapshot 20070405cvs.
- Extend the supported architectures from ia64 also to x86_64, i386 and ppc64.
- Spec file fixups.
- Split the package to its base and the `devel' part.
- Drop the statically built libraries.

* Sun Oct 01 2006 Jesse Keating <jkeating@redhat.com> - 0.98.5-3
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Sat Sep 22 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 0.98.5-2
- SELinux compatibility fix - stack is now non-exec (Jakub Jelinek suggestion).

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 0.98.5-1.1
- rebuild

* Sat May 27 2006 Alexandre Oliva <aoliva@redhat.com> - 0.98.5-1
- Import version 0.98.5.

* Thu Feb 09 2006 Florian La Roche <laroche@redhat.com>
- remove empty scripts

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 0.98.2-3.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Tue Mar 01 2005 Jeff Johnston <jjohnstn@redhat.com>	0.98.2.3
- Bump up release number

* Thu Nov 11 2004 Jeff Johnston <jjohnstn@redhat.com>	0.98.2.2
- Import version 0.98.2.

* Wed Nov 10 2004 Jeff Johnston <jjohnstn@redhat.com>	0.97.6
- Bump up release number

* Thu Aug 19 2004 Jeff Johnston <jjohnstn@redhat.com>	0.97.3
- Remove debug file from files list.

* Fri Aug 13 2004 Jeff Johnston <jjohnstn@redhat.com>	0.97.2
- Import version 0.97.

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Jun 09 2004  Elena Zannoni <ezannoni@redhat.com>	0.96.4
- Bump release number.

* Mon Feb 23 2004  Elena Zannoni <ezannoni@redhat.com>	0.96.3
- Bump release number.

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Jan 29 2004  Jeff Johnston <jjohnstn@redhat.com>	0.96.1
- Import version 0.96.

* Tue Jan 06 2004  Jeff Johnston <jjohnstn@redhat.com>	0.92.2
- Bump release number.

* Mon Oct 06 2003  Jeff Johnston <jjohnstn@redhat.com>	0.92.1
- Initial release

